@@ -34,6 +34,7 @@ class Database:
 
             
             if price_adj == False:
+
                 ohlc_result = json.loads(json.loads(response.content).replace("'", "\"").replace('False','0').replace('True','1'))
             else:
 
@@ -127,14 +128,6 @@ class Database:
                     elif freq == '1D':
                         df = df[['date','open','high','low','close','volume']]
 
-            df['date'] = df['date'].astype(int)
-            if 'T' in freq:
-                df['time'] = df['time'].astype(int)
-            else:
-                df['time'] = 0
-
-            df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
-
             return df
     
     def get_us_stock_ohlc(self, code, start_date, end_date):
@@ -216,7 +209,6 @@ class Database:
                 if year_month not in year_month_involved_list:
                     year_month_involved_list.append(year_month)
 
-            #if end_date >= int(expiry_date_dict[max(year_month_involved_list)].strftime('%Y%m%d')):
             year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
 
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
@@ -246,7 +238,6 @@ class Database:
             result_list = json.loads(json.loads(response.content).replace("'", "\""))
 
             df_list = []
-            date_time_list_list = []
 
             for result in result_list:
                 sub_df_list = []
@@ -273,7 +264,7 @@ class Database:
 
                     for i in range(len(date_list)):
                         date_item = date_list[i]
-
+    
                         if i + rolling_day <= len(date_list) - 1:
                             if date_list[i + rolling_day] == front_expiry_date:
                                 front_cut_off_date = date_item
@@ -290,35 +281,24 @@ class Database:
                         df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
                         df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
 
-                    df = df[df['date'] >= start_date]
-                    df = df[df['date'] <= end_date]
-                    df['date'] = df['date'].astype(str)
-                    df['time'] = df['time'].astype(str)
-                    df['time'] = df['time'].str.zfill(6)
-                    df['datetime'] = df['date'] + ' ' + df['time']
-
-                    df = df.reset_index(drop=True)
-                    date_time_list = df['datetime'].to_list()
-
-                    if len(date_time_list_list) > 0:
-                        date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
-                        if len(date_time_intersect) == 0:
-                            df_list.append(df)
-                    else:
-                        df_list.append(df)
-
-                    date_time_list_list += date_time_list
+                    df_list.append(df)
 
             cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date','RTH']
             df = pd.concat(df_list)
 
+            df = df[df['date'] >= start_date]
+            df = df[df['date'] <= end_date]
+            df['date'] = df['date'].astype(str)
+            df['time'] = df['time'].astype(str)
+            df['time'] = df['time'].str.zfill(6)
+            df['datetime'] = df['date'] + ' ' + df['time']
             df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
             df['RTH'] = df['RTH'].astype(bool)
             
             df = df[cols]
             df = df.set_index(keys='datetime')
             df = df.sort_index(ascending=True)
-
+    
             return df
     
         else:
@@ -926,8 +906,8 @@ class Database:
         link_str = link_url + '&' + token_str + '&' + database_str
         
         response = requests.get(link_str)
-        json1 = json.loads(response.content).replace("'", "\"").replace('nan','NaN')
-        result = json.loads(json1)
+        #result = json.loads(json.loads(response.content).replace("'", "\""))
+        result = ast.literal_eval(json.loads(response.content))
 
         df = pd.DataFrame(result)
         df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
@@ -941,7 +921,8 @@ class Database:
         
         df['share_issued'] = df['share_issued'].astype(int)
         df['market_capital'] = df['market_capital'].astype(int)
-
+        
+        
         return df
 
     def get_hk_ipo_hist(self):
@@ -1674,7 +1655,7 @@ def get_holiday_from_gov(year):
 
     return holiday_date_list, half_day_mkt_date_list
 
-def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_format = '%Y%m%d'):
+def get_hk_holiday_and_expiry_date(start_year, end_year, format='int'):
     holiday_date_list = []
     half_day_mkt_date_list = []
 
@@ -1701,7 +1682,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_forma
                     trading_days += 1
                 if trading_days == 2:
                     if format == 'str' or format == 'string':
-                        expiry_date = test_date.strftime(str_format)
+                        expiry_date = test_date.strftime('%Y%m%d')
                     elif format == 'int' or format == 'integer':
                         expiry_date = int(test_date.strftime('%Y%m%d'))
                     elif format == 'dt' or format == 'datetime':
@@ -1712,7 +1693,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_forma
     holiday_list = []
     for day in holiday_date_list:
         if format == 'str' or format == 'string':
-            holiday = day.strftime(str_format)
+            holiday = day.strftime('%Y%m%d')
         elif format == 'int' or format == 'integer':
             holiday = int(day.strftime('%Y%m%d'))
         elif format == 'dt' or format == 'datetime':
@@ -1722,7 +1703,7 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_forma
     half_day_mkt_list = []
     for day in half_day_mkt_date_list:
         if format == 'str' or format == 'string':
-            holiday = day.strftime(str_format)
+            holiday = day.strftime('%Y%m%d')
         elif format == 'int' or format == 'integer':
             holiday = int(day.strftime('%Y%m%d'))
         elif format == 'dt' or format == 'datetime':
